*;  KEYLCD-B.ASM
*;	Example program using the KEYPAD and LCD_PORT on the Axiom
*;       CMx12B32 boards.
*;

*; Memory Map Equates
RAMSTRT:	EQU	$0800	; start of internal ram
MONRAM:		EQU	$0A00	; monitor ram start
RAMSIZE:	EQU	$0400	; Size of internal ram
REGBS:  	EQU	$0000	; start of registers
ROMBS:  	EQU	$FD80	; start of initialization rom
DSTREE: 	EQU	$1000	; start of eeprom
DENDEE: 	EQU	$1FFF	; end of eeprom
STACK:		EQU	RAMSTRT+RAMSIZE	; top of stack

MONSTRT:        EQU     $2000   ; start of this program if running under monitor
PRGSTRT:        EQU     $8000   ; start of this program if running stand-alone

#include	equates.asm	; include register equates


*; RAM
        ORG  RAMSTRT

CNT1	RMB	1	; temporary count variable
TMP1	RMB	1	; temporary storage variable
OLDKEY	RMB	1	; save key value for debounce



**********************
; Program starts here *
**********************

;*	ORG	MONSTRT
	ORG	PRGSTRT

START:
	lds	#STACK		; initialize stack pointer (don't do this if under monitor)
	CLR	$0016		; COP TIMER OFF

; enable bus controls...
        movw    #$8CF0,$0A	; ENABLE EXPANDED WIDE BUS
        LDAA    #$77            ; SET MISC REGISTER, Flash on
        STAA    $13             ;
; wait for LCD power up
	jsr	delay40		; delay 80ms
	jsr	delay40

	jsr	INITKEY	; Initialize KEYPAD
	jsr	INITLCD	; Initialize LCD
	ldx	#PMT	; get message string
	jsr	LCDSTR	; display string
MainLoop:
	jsr	GETKEY	; get a key from keypad, returned in A
	jsr	LCDOUT	; display key value
	bra	MainLoop

; send string to LCd...
LCDSTR:
	ldaa	1,x+	; get byte to display
	beq	LCDSTRX	; if empty, quit
	jsr	LCDOUT	; display character]
	bra	LCDSTR	; loop for all characters
LCDSTRX:
	rts		; done with string

*;**************
*; TEXT TABLES *
*;**************
PMT:    FCC   'Press Key: '
	FCB	0


*; Include External Subroutine Files
#include        lcd12b.asm     ; include 12B32 LCD functions
#include        key12b.asm     ; include KEYPAD B32 functions

; define necessary reset vectors...
	ORG	$FFF8
	FDB	START
	FDB	START
	FDB	START
	FDB	START

         END


